@@ -30,7 +30,6 @@ from .._shared_files.context_managers import active_lattice_manager
 from .._shared_files.defaults import (
     _DEFAULT_CONSTRAINT_VALUES,
     attr_prefix,
-    default_constraints_dict,
     electron_dict_prefix,
     electron_list_prefix,
     generator_prefix,
@@ -236,7 +235,7 @@ class Electron:
                     kwargs={"key": i},
                     name=node_name,
                     function=None,
-                    metadata=default_constraints_dict.copy(),
+                    metadata=_DEFAULT_CONSTRAINT_VALUES.copy(),
                 )
 
                 active_lattice.transport_graph.add_edge(self.node_id, node_id, f"[{i}]")
@@ -272,7 +271,7 @@ class Electron:
                 kwargs={"attr": attr},
                 name=node_name,
                 function=None,
-                metadata=default_constraints_dict.copy(),
+                metadata=_DEFAULT_CONSTRAINT_VALUES.copy(),
             )
 
             active_lattice.transport_graph.add_edge(self.node_id, node_id, f".{attr}")
@@ -299,7 +298,7 @@ class Electron:
                 kwargs={"key": key},
                 name=node_name,
                 function=None,
-                metadata=default_constraints_dict.copy(),
+                metadata=_DEFAULT_CONSTRAINT_VALUES.copy(),
             )
 
             active_lattice.transport_graph.add_edge(self.node_id, node_id, f"[{key}]")
@@ -350,8 +349,9 @@ class Electron:
         # Setting metadata for default values according to lattice's metadata
         # If metadata is default, then set it to lattice's default
         for k in self.metadata:
-            if k not in consumable_constraints and self.get_metadata(k) is getattr(
-                _DEFAULT_CONSTRAINT_VALUES, k
+            if (
+                k not in consumable_constraints
+                and self.get_metadata(k) is _DEFAULT_CONSTRAINT_VALUES[k]
             ):
                 self.set_metadata(k, active_lattice.get_metadata(k))
 
@@ -408,7 +408,7 @@ class Electron:
             kwargs={key: value},
             name=prefix,
             function=to_electron_collection,
-            metadata=default_constraints_dict.copy(),
+            metadata=_DEFAULT_CONSTRAINT_VALUES.copy(),
         )
 
         graph.set_node_value(
@@ -466,7 +466,7 @@ class Electron:
                 kwargs=argument_kwargs,
                 name=parameter_prefix + str(some_value),
                 function=None,
-                metadata=default_constraints_dict.copy(),
+                metadata=_DEFAULT_CONSTRAINT_VALUES.copy(),
             )
             transport_graph.add_edge(argument_node, node_id, variable=key)
 
@@ -476,7 +476,7 @@ def electron(
     *,
     backend: Optional[
         Union[List[Union[str, "BaseExecutor"]], Union[str, "BaseExecutor"]]
-    ] = _DEFAULT_CONSTRAINT_VALUES.backend,
+    ] = _DEFAULT_CONSTRAINT_VALUES["backend"],
     # Add custom metadata fields here
 ) -> Callable:
     """Electron decorator to be called upon a function. Returns a new :obj:`Electron <covalent._workflow.electron.Electron>` object.
